@@ -6,6 +6,7 @@ from django import forms
 
 from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
+from django.core.urlresolvers import reverse
 
 from djangocodemirror import settings_local
 from djangocodemirror.fields import DjangoCodeMirrorField
@@ -14,7 +15,7 @@ THEME_CHOICES = [(v.split('/')[-1].split('.')[0], k) for k,v in settings_local.C
 
 # Try import for parser
 try:
-    from sveedocuments.parser import SourceReporter, map_parsing_errors
+    from rstview.parser import SourceReporter, map_parsing_errors
 except ImportError:
     # Dummy fallback
     def map_parsing_errors(error, *args, **kwargs):
@@ -43,7 +44,7 @@ class DjangoCodeMirrorSampleForm(forms.Form):
     """
     Sample form
     """
-    content = DjangoCodeMirrorField(label=u"DjangoCodeMirror", max_length=5000, required=True, codemirror_attrs=settings_local.CODEMIRROR_SETTINGS['djangocodemirror_sample_demo'])
+    content = DjangoCodeMirrorField(label=u"DjangoCodeMirror", max_length=50000, required=True, codemirror_attrs=settings_local.CODEMIRROR_SETTINGS['djangocodemirror_sample_demo'])
     
     def clean_content(self):
         """
@@ -63,19 +64,27 @@ class DjangoCodeMirrorSettingsForm(forms.Form):
     """
     Editor settings form
     """
-    #mode = forms.ChoiceField(label=_('mode'), choices=[(k, k) for k,v in settings_local.CODEMIRROR_MODES], required=False, help_text=_("The mode to use."))
     theme = forms.ChoiceField(label=_('theme'), initial=settings_local.DJANGOCODEMIRROR_DEFAULT_THEME, choices=THEME_CHOICES, required=False, help_text=_("The theme to style the editor with."))
-    smartIndent = forms.BooleanField(label=_('smart indent'), initial=True, required=False, help_text=_("Whether to use the context-sensitive indentation that the mode provides (or just indent the same as the line before)."))
-    indentUnit = forms.IntegerField(label=_('indent unit'), initial=2, required=True, help_text=_("How many spaces a block (whatever that means in the edited language) should be indented."))
-    tabSize = forms.IntegerField(label=_('tab size'), initial=4, required=True, help_text=_("The width of a tab character."))
-    indentWithTabs = forms.BooleanField(label=_('indent with tabs'), initial=False, required=False, help_text=_("Whether, when indenting, the first N*tabSize spaces should be replaced by N tabs."))
-    lineWrapping = forms.BooleanField(label=_('line wrapping'), initial=False, required=False, help_text=_("Whether CodeMirror should scroll or wrap for long lines."))
-    no_tab_char = forms.BooleanField(label=_('avoid tabulation'), initial=False, required=False, help_text=_("Disable usage of any tabulation character, instead each tabulation will be replaced by N space where N is the value of the 'tab size' option."))
+    lineWrapping = forms.BooleanField(label=_('line wrapping'), initial=True, required=False, help_text=_("Whether CodeMirror should scroll or wrap for long lines."))
+    no_tab_char = forms.BooleanField(label=_('avoid tabulation'), initial=True, required=False, help_text=_("Disable usage of any tabulation character, instead each tabulation will be replaced by 4 space characters."))
     
     def __init__(self, *args, **kwargs):
         self.helper = get_form_helper()
+        self.helper.form_action = reverse('djangocodemirror-settings')
         
         super(DjangoCodeMirrorSettingsForm, self).__init__(*args, **kwargs)
     
     def save(self, *args, **kwargs):
+        no_tab_char = self.cleaned_data.get('no_tab_char')
+        # Set the needed options to avoid tabulation character usage
+        if no_tab_char:
+            self.cleaned_data.update({
+                "indentUnit": 4,
+                "tabSize": 4,
+                "indentWithTabs": False,
+            })
+        else:
+            self.cleaned_data.update({
+                "indentWithTabs": True,
+            })
         return self.cleaned_data
